# safethread/__init__.py

"""
safethread

This package provides utilities for handling threading and concurrency in Python.

Modules:
    - thread: Provides a classes for managing threads safely (using threading module primitives).
    - process: Provides a classes for managing processes safely (using multiprocessing module primitives).
    - utils: Includes utilities classes used throughout the code.
"""
